@@ -98,11 +98,16 @@ plot_type_int <- function(model,
 
 
     # compute marginal effects for interaction terms
+    pred.type <- switch(pred.type,
+      fe = "fixed",
+      re = "random",
+      pred.type
+    )
 
     dat <- ggeffects::ggpredict(
       model = model,
       terms = ia,
-      ci.lvl = ci.lvl,
+      ci_level = ci.lvl,
       type = pred.type,
       full.data = FALSE,
       ...
@@ -132,20 +137,20 @@ plot_type_int <- function(model,
 
     p <- graphics::plot(
       dat,
-      ci = !is.na(ci.lvl),
+      show_ci = !is.na(ci.lvl),
       facets = facets,
-      rawdata = show.data,
+      show_data = show.data,
       colors = geom.colors,
       jitter = jitter,
-      use.theme = FALSE,
+      use_theme = FALSE,
       case = case,
-      show.legend = show.legend,
-      dot.alpha = dot.alpha,
+      show_legend = show.legend,
+      dot_alpha = dot.alpha,
       alpha = alpha,
       dodge = dodge,
-      log.y = log.y,
-      dot.size = dot.size,
-      line.size = line.size
+      log_y = log.y,
+      dot_size = dot.size,
+      line_size = line.size
     )
 
     # set axis and plot titles
